==> qtjambi-designer-debuginfo-macos-6.5.4.jar: sources/QtJambiDesigner/QDesignerFormWindowToolInterface_shell.h <==
#ifndef QDESIGNERFORMWINDOWTOOLINTERFACE_SHELL_H
#define QDESIGNERFORMWINDOWTOOLINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractformwindowtool.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerFormWindowToolInterface_shell : public QDesignerFormWindowToolInterface, public QtJambiShellInterface
{
public:
    QDesignerFormWindowToolInterface_shell(QObject* parent0 = nullptr);
    ~QDesignerFormWindowToolInterface_shell() override;

    QAction* action() const override;
    void activated() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QDesignerFormEditorInterface* core() const override;
    void customEvent(QEvent* event0) override;
    void deactivated() override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QWidget* editor() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QDesignerFormWindowInterface* formWindow() const override;
    bool handleEvent(QWidget* widget0, QWidget* managedWidget1, QEvent* event2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerFormWindowToolInterface_access : public QDesignerFormWindowToolInterface
{
    jobject __qt_action(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_activated(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_core(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_deactivated(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_editor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_formWindow(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_handleEvent_QWidget_ptr_QWidget_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0, QtJambiNativeID managedWidget1, QtJambiNativeID event2);
};

#endif // QDESIGNERFORMWINDOWTOOLINTERFACE_SHELL_H

==> qtjambi-designer-debuginfo-macos-6.6.3.jar: sources/QtJambiDesigner/QDesignerFormWindowToolInterface_shell.h <==
#ifndef QDESIGNERFORMWINDOWTOOLINTERFACE_SHELL_H
#define QDESIGNERFORMWINDOWTOOLINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractformwindowtool.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerFormWindowToolInterface_shell : public QDesignerFormWindowToolInterface, public QtJambiShellInterface
{
public:
    QDesignerFormWindowToolInterface_shell(QObject* parent0 = nullptr);
    ~QDesignerFormWindowToolInterface_shell() override;

    QAction* action() const override;
    void activated() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QDesignerFormEditorInterface* core() const override;
    void customEvent(QEvent* event0) override;
    void deactivated() override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QWidget* editor() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QDesignerFormWindowInterface* formWindow() const override;
    bool handleEvent(QWidget* widget0, QWidget* managedWidget1, QEvent* event2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerFormWindowToolInterface_access : public QDesignerFormWindowToolInterface
{
    jobject __qt_action_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_activated(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_core_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_deactivated(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_editor_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_formWindow_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_handleEvent_QWidget_ptr_QWidget_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0, QtJambiNativeID managedWidget1, QtJambiNativeID event2);
};

#endif // QDESIGNERFORMWINDOWTOOLINTERFACE_SHELL_H
